Changelog — pycollect 0.2.2 documentation

### Navigation

- ☰
- pycollect-0.2.2 »

Fork me on GitHub

# Changelog

## 0.2.2 (2020-02-29)

- Lift __init__.py requirement for considering a path as importable

## 0.2.1 (2020-02-29)

- Fix module finder for Windows

## 0.2.0 (2020-02-28)

- Added utility function to find a file’s module name

## 0.1.1 (2020-02-24)

- Update docs

## 0.1.0 (2019-12-22)

- First beta release

## 0.0.1 (2019-09-01)

- Fix GitHub release workflow.

## 0.0.0 (2019-08-31)

- First release on PyPI.

### Navigation

- index
- modules |
- previous |